@@ -114,7 +114,7 @@ class Firebot:
         """
         Returns the value of metadata for a user. Metadata postional argument is case sensitive. 
         """
-        id = self.get_viewerID(user)
+        id = self.getViewerID(user)
         if id != None:
             attempts = 0
             while attempts <= totalAttempts:
@@ -176,7 +176,7 @@ class Firebot:
         """
         Returns the amount a user has of the given currency
         """
-        id = self.get_currencyID(currency)
+        id = self.getCurrencyID(currency)
         if id != None:
             attempts = 0
             while attempts <= totalAttempts:
